@@ -1,19 +1,15 @@
 from pathlib import Path
 
 from rich import print
-from typer import Option
 
-from deckz.cli import app
+from deckz.cli import app, option_workdir
 from deckz.config import get_config
 from deckz.paths import Paths
 
 
 @app.command()
-def print_config(
-    workdir: Path = Option(
-        Path("."), help="Path to move into before running the command"
-    )
-) -> None:
+@option_workdir
+def print_config(workdir: Path) -> None:
     """Print the resolved configuration."""
     config = get_config(Paths.from_defaults(workdir))
     max_length = max(len(key) for key in config)
