@@ -1,9 +1,7 @@
 from logging import getLogger
 from pathlib import Path
 
-from typer import Option
-
-from deckz.cli import app
+from deckz.cli import app, option_workdir
 from deckz.paths import Paths
 from deckz.uploading import Uploader
 
@@ -11,11 +9,8 @@ _logger = getLogger(__name__)
 
 
 @app.command()
-def upload(
-    workdir: Path = Option(
-        Path("."), help="Path to move into before running the command"
-    )
-) -> None:
+@option_workdir
+def upload(workdir: Path) -> None:
     """Upload pdfs to Google Drive."""
     paths = Paths.from_defaults(workdir)
     Uploader(paths)
